@@ -1,6 +1,7 @@
 from loguru import logger
 import traceback
 import asyncio
+import beeprint
 
 
 class AsyncTestCase:
@@ -20,7 +21,8 @@ class AsyncTestCase:
 
     def assertEqual(self, a, b):
         if a != b:
-            raise ValueError(f"{a}!={b}")
+            raise ValueError(
+                f"{beeprint.pp(a, output=False, sort_keys=False, string_break_enable=False)}!=\n{beeprint.pp(b, output=False, sort_keys=False, string_break_enable=False)}")
 
     def assertTrue(self, a):
         self.assertEqual(True, a)
